@@ -87,14 +87,14 @@ class NumPyChain(Chain):
     def __len__(self) -> int:
         return self._draw_idx
 
-    def get_draws(self, var_name: str) -> numpy.ndarray:
-        return self._samples[var_name][: self._draw_idx]
+    def get_draws(self, var_name: str, slc: slice = slice(None)) -> numpy.ndarray:
+        return self._samples[var_name][: self._draw_idx][slc]
 
     def get_draws_at(self, idx: int, var_names: Sequence[str]) -> Dict[str, numpy.ndarray]:
         return {vn: numpy.asarray(self._samples[vn][idx]) for vn in var_names}
 
-    def get_stats(self, stat_name: str) -> numpy.ndarray:
-        return self._stats[stat_name][: self._draw_idx]
+    def get_stats(self, stat_name: str, slc: slice = slice(None)) -> numpy.ndarray:
+        return self._stats[stat_name][: self._draw_idx][slc]
 
     def get_stats_at(self, idx: int, stat_names: Sequence[str]) -> Dict[str, numpy.ndarray]:
         return {sn: numpy.asarray(self._stats[sn][idx]) for sn in stat_names}
